#!/bin/bash

export COMPONENT_HASH=fabcc8c2f880d40490ea248a1732119a909e7050
PKG_VERSION=1.1+cdh6.2.1
FULL_VERSION=1.1-cdh6.2.1
BASE_VERSION=1.1
PKG_RELEASE=1425774
CDH_CUSTOMER_PATCH=p0
CDH_PARCEL_CUSTOM_VERSION=1.1+cdh6.2.1-1425774.xenial
